@@ -15,7 +15,7 @@
 
 
 # NOTE :
-#   It would be nice to add done projection to input Biomod.models.object
+#   It would be nice to add done projections to input Biomod.models.object
 #   .BIOMOD_Projection.check.args <- may be reorder variables if necessary
 
 ####################################################################################################
@@ -35,12 +35,16 @@
   silent <- args$silent # echo advancement or not
   do.stack <- args$do.stack # store output in a lone stack
   clamping.level <- args$clamping.levels # remove all cells where at least clamping.level variables are out of their calibrating range
-  clamping.value <- args$clamping.value # reference value for clamped cells 
+#   clamping.value <- args$clamping.value # reference value for clamped cells 
   output.format <- args$output.format # raster output format
+  keep.in.memory <- args$keep.in.memory # store results on memory or only on hard drive
   
   if(is.null(silent)) silent <- FALSE
   if(is.null(do.stack)) do.stack <- TRUE
-  if(is.null(clamping.value)) clamping.value <- -1
+#   if(is.null(clamping.value)) clamping.value <- -1
+  if(is.null(keep.in.memory)) keep.in.memory <- TRUE
+  
+  if(!do.stack | !keep.in.memory) rasterOptions(todisk=TRUE)
   
   if(is.null(output.format)){
     if(!inherits(new.env,"Raster"))
@@ -81,8 +85,13 @@
               sp.name =  modeling.output@sp.name,
               expl.var.names = modeling.output@expl.var.names,
               models.projected = selected.models,
-              rescaled.models = modeling.output@rescal.all.models,
-              xy.coord = xy.new.env)
+              scaled.models = modeling.output@rescal.all.models,
+              xy.coord = xy.new.env,
+              modeling.object.id = modeling.output@modeling.id)
+  
+  # add link to biomod2 modeling object
+  proj_out@modeling.object@link = modeling.output@link
+  
   
   # adapting the proj slot to projection data type (e.g. rasterStack, array)
 #   if(!do.stack){
@@ -121,13 +130,14 @@
 
   }
   
-  # 2. Doing projection -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= #
+  # 2. Making projections -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= #
   
   proj <- lapply(selected.models, function(mod.name){
     cat("\n\t> Projecting",mod.name,"...")
     ## load biomod model
-    mod <- get(load(file.path(modeling.output@sp.name, "models", mod.name)))
-    rm(list=mod.name)
+    BIOMOD_LoadModels(modeling.output, full.name=mod.name, as="mod")
+#     mod <- get(load(file.path(modeling.output@sp.name, "models", mod.name)))
+#     rm(list=mod.name)
     if(!do.stack){
       dir.create(file.path(modeling.output@sp.name,paste("proj_", proj.name, sep=""), "individual_projections"), 
                  showWarnings = FALSE, recursive = TRUE, mode = "0777")
@@ -147,7 +157,8 @@
     proj <- DF_to_ARRAY(proj)
   }
   
-  proj_out@proj@val <- proj
+  if( keep.in.memory)
+    proj_out@proj@val <- proj
   
   ## save projections
   assign(x = paste("proj_",proj.name, "_", modeling.output@sp.name, sep=""),
@@ -236,16 +247,22 @@
 #   }
   
   proj_out@type <- class(proj_out@proj@val)
-  if(do.stack){
+  
+  if(keep.in.memory)
     proj_out@proj@inMemory <- TRUE
+  else proj_out@proj@inMemory <- FALSE
+  
+  if(do.stack){
     proj_out@proj@link <- file.path(modeling.output@sp.name, paste("proj_", proj.name, sep=""), 
                                 paste("proj_",proj.name, "_", modeling.output@sp.name, output.format, sep="") )    
   } else{
-    proj_out@proj@inMemory <- FALSE
     proj_out@proj@link <-file.path(modeling.output@sp.name, paste("proj_", proj.name, sep=""), "individual_projections")
   }
 
-  
+  # save a copy of output object without value to be lighter
+  assign(paste(modeling.output@sp.name,".", proj.name, ".projection.out", sep=""), free(proj_out))
+  save(list = paste(modeling.output@sp.name,".", proj.name, ".projection.out", sep=""),
+       file = file.path(modeling.output@sp.name, paste("proj_", proj.name, sep=""), paste(modeling.output@sp.name,".", proj.name, ".projection.out", sep="")))
   
 #   # 3. Removing Maxent Tmp Data
 #   if(file.exists(paste(modeling.output@sp.name, "/proj_", proj.name,'/MaxentTmpData/',sep=''))){
@@ -313,7 +330,7 @@
   }
   
   # check that given models exits
-  files.check <- paste(modeling.output@sp.name,'/models/',selected.models,sep='')
+  files.check <- paste(modeling.output@sp.name,'/models/',modeling.output@modeling.id,"/",selected.models,sep='')
   not.checked.files <- c(grep('MAXENT', files.check), grep('SRE', files.check))
   if(length(not.checked.files) > 0){files.check <- files.check[-not.checked.files]}
   missing.files <- files.check[!file.exists(files.check)]
@@ -359,7 +376,7 @@
       
   ## do.stack
   if(class(new.env) != 'RasterStack'){
-    do.stack <- TRUE
+    # do.stack <- TRUE
   } else{
     if(do.stack){
       # test if there is memory enough to work with RasterStack
